pub fn load_rules(toml_str: &str) -> Result<CustomRulesFile, String>Expand description
Load custom rules from a TOML string. Inputs larger than 1 MiB are rejected before parsing to bound memory + parse time.
pub fn load_rules(toml_str: &str) -> Result<CustomRulesFile, String>Load custom rules from a TOML string. Inputs larger than 1 MiB are rejected before parsing to bound memory + parse time.